whatsthedamage.api package
==========================

.. automodule:: whatsthedamage.api
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   whatsthedamage.api.v1
   whatsthedamage.api.v2

Submodules
----------

whatsthedamage.api.docs module
------------------------------

.. automodule:: whatsthedamage.api.docs
   :members:
   :show-inheritance:
   :undoc-members:

whatsthedamage.api.error\_handlers module
-----------------------------------------

.. automodule:: whatsthedamage.api.error_handlers
   :members:
   :show-inheritance:
   :undoc-members:

whatsthedamage.api.helpers module
---------------------------------

.. automodule:: whatsthedamage.api.helpers
   :members:
   :show-inheritance:
   :undoc-members:
